<?php

namespace JReviewsDeploy;

defined('_JEXEC') or die;

use Joomla\CMS\Extension\ExtensionHelper;
use Joomla\CMS\Factory;

function htmxRequest()
{
    return Factory::getApplication()->getInput()->server->get('HTTP_HX_REQUEST') == 'true';
}

function jr_config($name) 
{
    $db = Factory::getContainer()->get('DatabaseDriver');
    
    $query = $db->getQuery(true);

    $query
        ->select($db->quoteName('value'))
        ->from($db->quoteName('#__jreviews_config'))
        ->where($db->quoteName('id') . ' = ' . $db->quote($name));
    
    $db->setQuery($query);
    
    return $db->loadResult();    
}

function jr_license()
{
    $db = Factory::getContainer()->get('DatabaseDriver');
    
    $tableName = $db->getPrefix() . 'jreviews_license';

    if (! in_array($tableName, $db->getTableList())) {
        return false;
    }
    
    $query = $db->getQuery(true);

    $query
        ->select($db->quoteName('value'))
        ->from($db->quoteName('#__jreviews_license'))
        ->where($db->quoteName('id') . ' = ' . $db->quote('license'));
    
    $db->setQuery($query);
    
    return $db->loadResult();    
}

function component_version($name)
{
    $manifest = ExtensionHelper::getExtensionRecord($name, 'component')?->manifest_cache;
        
    if (! $manifest) {
        return null;
    }
    
    $manifest = json_decode($manifest);
    
    return $manifest->version;
}

function jr_addons()
{
    $db = Factory::getContainer()->get('DatabaseDriver');
    
    $query = $db->getQuery(true);

    $query
        ->select($db->quoteName('title'))
        ->select($db->quoteName('name'))
        ->select($db->quoteName('manifest'))
        ->from($db->quoteName('#__jreviews_addons'))
        ->order('title');
    
    $db->setQuery($query);
    
    $addons = $db->loadObjectList();

    if (! $addons) {
        return [];
    }

    foreach ($addons as & $addon) {
        $manifest =  json_decode($addon->manifest);
        $addon->version  = $manifest->version;
    }

    $last = [
        'paymentcoinbase',
        'paymentmollie',
        'paymentstripe',
    ];

    usort($addons, function ($a, $b) use ($last) {
        if (in_array($a->name, $last) && !in_array($b->name, $last)) {
            return 1;
        } elseif (!in_array($a->name, $last) && in_array($b->name, $last)) {
            return -1;
        }
        return 0;
    });  
        
    return $addons;
}

function jr_addons_array()
{
    $result = [];

    foreach (jr_addons() as $addon) {
        $result[$addon->name] = $addon->version;
    }

    return $result;
}
